==> struts-6.8.0-src.zip: struts-6.8.0/src/core/src/main/java/org/apache/struts2/config/entities/BeanSelectionConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.config.entities;

import com.opensymphony.xwork2.config.BeanSelectionProvider;
import com.opensymphony.xwork2.inject.Container;

public class BeanSelectionConfig {

    private final Class<? extends BeanSelectionProvider> clazz;
    private final String name;

    public BeanSelectionConfig(Class<? extends BeanSelectionProvider> clazz) {
        this(clazz, Container.DEFAULT_NAME);
    }

    public BeanSelectionConfig(Class<? extends BeanSelectionProvider> clazz, String name) {
        this.clazz = clazz;
        this.name = name;
    }

    public Class<? extends BeanSelectionProvider> getClazz() {
        return clazz;
    }

    public String getName() {
        return name;
    }
}

==> struts-7.1.1-src.zip: struts-7.1.1/src/core/src/main/java/org/apache/struts2/config/entities/BeanSelectionConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.config.entities;

import org.apache.struts2.config.BeanSelectionProvider;
import org.apache.struts2.inject.Container;

public class BeanSelectionConfig {

    private final Class<? extends BeanSelectionProvider> clazz;
    private final String name;

    public BeanSelectionConfig(Class<? extends BeanSelectionProvider> clazz) {
        this(clazz, Container.DEFAULT_NAME);
    }

    public BeanSelectionConfig(Class<? extends BeanSelectionProvider> clazz, String name) {
        this.clazz = clazz;
        this.name = name;
    }

    public Class<? extends BeanSelectionProvider> getClazz() {
        return clazz;
    }

    public String getName() {
        return name;
    }
}
